@@ -6,21 +6,16 @@ from pathlib import Path
 HOME_DIR = home = str(Path.home())
 ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
 
-TODAY = datetime.datetime.now().date()
-YESTERDAY = (datetime.datetime.now() - datetime.timedelta(days=1)).date()
-
-TODAY_STR = TODAY.strftime("%Y-%m-%d")
-YESTERDAY_STR = YESTERDAY.strftime("%Y-%m-%d")
-
-FORTNIGHT_AGO = (datetime.datetime.now() - datetime.timedelta(days=14)).date()
-ONE_YEAR_AGO = (datetime.datetime.now() - datetime.timedelta(days=364)).date()
-
 CONFIG_FILE_LOCATION = f"{HOME_DIR}/.sylo/sylo.cfg"
 HOME_DIR_CREATE = f"mkdir {HOME_DIR}/.sylo"
 SYLO_HOME = f"{HOME_DIR}/.sylo"
 
 
-WELCOME_CHOICES = ("", "h", "q", "s", "t", "y", "i", "a")
+INPUT_OPTIONS = {
+    "home": ["", "h", "q", "s", "t", "y", "i", "a"],
+    "task_menu": ["", "c", "m", "n", "d"],
+}
+
 
 TIMER_DEFAULTS = {
     "work": {
@@ -45,3 +40,5 @@ BOOTSTRAP_SQL = f"{ROOT_DIR}/database_interactions/bootstrap.sql"
 
 INSIGHTS_FILE_SESSIONS = f"{HOME_DIR}/.sylo/insights_sessions.dat"
 INSIGHTS_FILE_POMS = f"{HOME_DIR}/.sylo/insights_poms.dat"
+FORTNIGHT_AGO = (datetime.datetime.now() - datetime.timedelta(days=14)).date()
+ONE_YEAR_AGO = (datetime.datetime.now() - datetime.timedelta(days=364)).date()
