@@ -42,7 +42,8 @@ class Durations:
 
 @dataclass
 class Config:
-    theme_color = "lblue"
+    theme_color = "rainbow"
+    fewer_colors = 0
     audio_file = None
     work_time = 25
     rest_time = 5
@@ -62,15 +63,6 @@ class ConfigFile:
         if self.is_config is True:
             config_file = self.load_config()
             logger.info(config_file)
-            try:
-                general = config_file["general"]
-                logger.info(f"CONFIG: general from file: {general}")
-                config.theme_color = general["theme"]
-                logger.info(f"CONFIG:set theme_color to {config.theme_color}")
-
-            except KeyError as k:
-                logger.info(k)
-                pass
             try:
                 general = config_file["general"]
                 config.audio_file = general["audio_file"]
@@ -85,7 +77,6 @@ class ConfigFile:
             except KeyError as k:
                 logger.info(k)
                 pass
-
             try:
                 durations = config_file["durations"]
                 logger.info(f"CONFIG: durations from file: {durations}")
@@ -96,6 +87,21 @@ class ConfigFile:
             except KeyError as k:
                 logger.info(k)
                 pass
+            try:
+                general = config_file["display"]
+                logger.info(f"CONFIG: general from file: {general}")
+                config.theme_color = general["theme"]
+                logger.info(f"CONFIG:set theme_color to {config.theme_color}")
+            except KeyError as k:
+                logger.info(k)
+                pass
+            try:
+                general = config_file["display"]
+                config.fewer_colors = general["fewer_colors"]
+                logger.info(f"CONFIG:set simple_colors to {config.fewer_colors}")
+            except KeyError as k:
+                logger.info(k)
+                pass
 
 
 class Database:
