@@ -90,14 +90,10 @@ class Timer:
             leave=False,
             desc=self.display.print_timer(self.mode, self.mins, self.tasks),
             unit=" seconds",
-            bar_format="%s{l_bar}%s%s{bar}%s%s{r_bar}%s"
+            bar_format="{l_bar}%s{bar}%s{r_bar}"
             % (
-                self.display.color_map(self.config.theme_color),
-                Fore.RESET,
                 self.display.color_map(self.bar_color),
                 Fore.RESET,
-                self.display.color_map(self.config.theme_color),
-                Fore.RESET,
             ),
             smoothing=True,
             ncols=70,
@@ -278,7 +274,7 @@ class Sylo:
 
     def show_task(self, dates, with_id: bool = False):
         for date in dates:
-            print(self.display.col(f"---------------------------- {date}"))
+            print(self.display.col(f"--------------------------------- {date}", "lblue"))
             self.tasks = database.select(
                 f"SELECT"
                 f'"id",'
@@ -419,9 +415,9 @@ class Sylo:
             if complete is True:
                 self.sound_obj.play_sound()
                 self.durations.total_rest_mins += secs_passed
+                self.mode = flip_mode(self.mode)
             else:
                 self.durations.total_rest_mins += secs_passed
-            self.mode = flip_mode(self.mode)
             database.execute(
                 'INSERT INTO sessions ("session_date", "time_worked", "time_rested")'
                 f"VALUES ('{get_today()}',"
@@ -437,9 +433,9 @@ class Sylo:
                 self.sound_obj.play_sound()
                 self.durations.total_work_mins += self.durations.work.mins
                 self.durations.poms += 1
+                self.mode = flip_mode(self.mode)
             else:
                 self.durations.total_work_mins += secs_passed
-            self.mode = flip_mode(self.mode)
             database.execute(
                 'INSERT INTO sessions ("session_date", "time_worked", "time_rested")'
                 f"VALUES ('{get_today()}',"
@@ -515,6 +511,7 @@ def config_allocation(args, config, durations: Durations, display: Display):
     display.theme_color = config.theme_color
     display.theme = display.color_map(config.theme_color)
     display.pom_name = config.pom_name
+    display.simple_colors = config.fewer_colors
     logger.info(display.theme)
     if args.audio_file:
         config.audio_file = args.audio_file
